<?php

namespace Teknisa\CUS\Modules\Parametros\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;


class Cus01800ProdutosNaoEstocaveis extends \Teknisa\GER\Controllers\TeknisaCrud {
	protected $crudService;
	protected $dataSourceName;
	protected $parameterBagColumns = array();
	protected $environment;
	protected $connection;
	protected $newCode;
	protected $dataSourceManager;
	
	public function __construct($crudService, $parameterBagColumns, $environment, $connection, $newCode, $dataSourceManager) {
		$this->crudService = $crudService;
		$this->parameterBagColumns = $parameterBagColumns;
		$this->environment = $environment;
		$this->connection = $connection;
		$this->newCode = $newCode;
		$this->dataSourceManager = $dataSourceManager;
	}
    
    public function deletePosEst(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            foreach($rows as $row){
                $sql = "DELETE POSESTDIA 
                        WHERE
                        (CDFILIAL  = :CDFILIAL)  AND
                        (CDPRODUTO = :CDPRODUTO)";
                
                $params = array(
                    "CDFILIAL" => $row['CDFILIAL'],
                    "CDPRODUTO" => $row['CDPRODUTO']
                );
            
                $std = $this->connection->prepare($sql);
                $std->execute($params);
            }
        } catch (Exception $e) {
            throw $e;
        }
    }

    public function automaticoEstocavel(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->connection->beginTransaction();
        try {
            $this->updateEstoqAut($row);
            $this->deletePosEstAut($row);
            $this->connection->commit();
        } catch (Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    private function updateEstoqAut($row){

        $tamanho = 10;
        $completaCom = 'z';
        $row['CDARVPRODFIN'] = str_pad($row['CDARVPRODFIN'], 10, 'z', STR_PAD_RIGHT);

        $sql = "UPDATE PRODFILI
                SET
                    IDCNTRESTOQ = :P_CONTESTO
                WHERE
                CDFILIAL = :P_FILIAL AND
                EXISTS(SELECT
                        CDPRODUTO
                        FROM
                            PRODUTO
                        WHERE
                        (CDPRODUTO = PRODFILI.CDPRODUTO) AND
                        (CDARVPROD BETWEEN :P_INICIAL AND :P_FINAL))";
        
        $params = array(
            "P_CONTESTO" => $row['NAOESTOCAVEL'],
            "P_FILIAL" => $row['CDFILIAL'],
            "P_INICIAL" => $row['CDARVPRODINI'],
            "P_FINAL" => $row['CDARVPRODFIN']
        );
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }

    private function deletePosEstAut($row){
        $sql = "DELETE POSESTDIA
                WHERE
                    CDFILIAL = :P_CDFILIAL
                    AND CDPRODUTO IN (
                        SELECT
                            CDPRODUTO
                        FROM
                            PRODFILI
                        WHERE
                            PRODFILI.CDFILIAL = :P_CDFILIAL
                            AND PRODFILI.IDCNTRESTOQ = 'N'
                    )";
        
        $params = array(
            "P_CDFILIAL" => $row['CDFILIAL']
        );
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
}